@@ -26,6 +26,8 @@ Don't blame me for the pure Gruik style please
 #include<string.h>              /* strcat */
 #include<ctype.h>               /* toupper */
 #include<stdio.h>
+#include<fcntl.h>
+#include<unistd.h>
 /* chmod */
 #include <sys/types.h>
 #include <sys/stat.h>
@@ -226,6 +228,32 @@ void sauver(GtkButton * button, char **laliste)
     fullpath = malloc(100 * sizeof(char));
     sprintf(fullpath, "%s/.fluxbox/init", getenv("HOME"));
     chmod(fullpath, S_IRUSR | S_IWUSR);
+	{
+		/*
+		 * try to make a backup
+		 */
+		char tmp_buff[BUFSIZ+1],*ptr;
+		int source_fd, dest_fd, rdlen;
+
+		memset(tmp_buff,0,BUFSIZ+1);
+
+		ptr=strrchr(fullpath,'/');
+		if(ptr && ptr-fullpath<BUFSIZ) {
+			strncpy(tmp_buff,fullpath,ptr-fullpath);
+			snprintf(tmp_buff,BUFSIZ,"%s/init-FCONFBKP.old",tmp_buff);
+			dest_fd = open(tmp_buff,O_WRONLY|O_TRUNC|O_CREAT,0666);
+			source_fd = open(fullpath,O_RDONLY);
+			if( dest_fd == -1 || source_fd == -1 ) {
+				if(dest_fd<0) close(dest_fd);
+				if(source_fd<0) close(source_fd);
+			} else {
+				while((rdlen=read(source_fd,tmp_buff,BUFSIZ))>0)
+					write(dest_fd,tmp_buff,rdlen);
+				close(source_fd);
+				close(dest_fd);
+			}
+		}
+	}
     file = fopen(fullpath, "r+");
 
     for (n = 0; n < nblignes + 1; n++) {    /* scan all lines */
@@ -589,7 +617,7 @@ items = g_list_append(items, "LeftToRight");
     gtk_box_pack_start(GTK_BOX(vbox1), s[17].wid, FALSE, FALSE, 0);
     s[18].wid=newlitteral(_("Theme file location (*)"),s[18].value,_("Change the location of the theme file"),tip);
     gtk_box_pack_start(GTK_BOX(vbox1), s[18].wid, FALSE, FALSE, 0);
-    s[19].wid=newlitteral(_("Time format"),s[19].value,_("%y:year(YY)\n%Y:year(YYYY)\n%m:month\n%d:day\n%H:hour(24)\n%h:hour(12)\n%M:minutes\n%p:meridian"),tip);
+    s[19].wid=newlitteral(_("Time format"),s[19].value,_("%y:year(YY)\n%Y:year(YYYY)\n%m:month\n%d:day\n%H:hour(24)\n%I:hour(12)\n%M:minutes\n%p:meridian"),tip);
     gtk_box_pack_start(GTK_BOX(vbox1), s[19].wid, FALSE, FALSE, 0);
         
     items = NULL;
@@ -664,7 +692,9 @@ GtkWidget *newkey(int Ctrl, int Alt, int Shift, int Win, GList * liste, char *va
     gtk_entry_set_text(GTK_ENTRY(key), touche);
 
     del = gtk_button_new_with_label("Del");
-    g_signal_connect (G_OBJECT(del), "clicked", G_CALLBACK(delkey), hbox);
+/*    g_signal_connect (G_OBJECT(del), "clicked", G_CALLBACK(delkey), hbox);*/
+	gtk_signal_connect (GTK_OBJECT(del), "clicked", GTK_SIGNAL_FUNC(delkey), hbox);             
+
 
     gtk_box_pack_start(GTK_BOX(hbox), m1, FALSE, FALSE, 1);
     gtk_box_pack_start(GTK_BOX(hbox), m2, FALSE, FALSE, 1);
@@ -715,6 +745,32 @@ void savekeys(GtkButton * but, GtkBox ** boites)
     fclose(file);
     free(buf);
     initpath = expandFilename(initpath);
+	{
+		/*
+		 * try to make a backup
+		 */
+		char tmp_buff[BUFSIZ+1],*ptr;
+		int source_fd, dest_fd, rdlen;
+
+		memset(tmp_buff,0,BUFSIZ+1);
+
+		ptr=strrchr(initpath,'/');
+		if(ptr && ptr-initpath<BUFSIZ) {
+			strncpy(tmp_buff,initpath,ptr-initpath);
+			snprintf(tmp_buff,BUFSIZ,"%s/keys-FCONFBKP.old",tmp_buff);
+			dest_fd = open(tmp_buff,O_WRONLY|O_TRUNC|O_CREAT,0666);
+			source_fd = open(initpath,O_RDONLY);
+			if( dest_fd == -1 || source_fd == -1 ) {
+				if(dest_fd<0) close(dest_fd);
+				if(source_fd<0) close(source_fd);
+			} else {
+				while((rdlen=read(source_fd,tmp_buff,BUFSIZ))>0)
+					write(dest_fd,tmp_buff,rdlen);
+				close(source_fd);
+				close(dest_fd);
+			}
+		}
+	}
     file = fopen(initpath, "w");
     if (file == NULL) {
         g_print(_("Can't open %s for writing\n"), initpath);
