@@ -12,6 +12,7 @@ Please, change the menu location with fluxconf to a writable one\n\
  (e.g ~/.fluxbox/fluxbox-menu).\n\
 Fluxmenu will then be able to save your fluxbox menu configuration.\n")
 
+char *expandFilename(char * filename) ;
 #ifdef GTK2
 enum {
     TYPE,
@@ -237,6 +238,7 @@ GtkWidget *plop(void)
         }
     }
     fclose(file);
+    initpath = expandFilename(initpath);
     file = fopen(initpath, "r");
     if (file == NULL) {
         g_print("Can't open %s : %s\n", initpath,strerror(errno));
@@ -360,6 +362,33 @@ void savemenu(void)
         }
     }
     fclose(file);
+    initpath = expandFilename(initpath);
+	{
+		/*
+		 * try to make a backup
+		 */
+		char tmp_buff[BUFSIZ+1],*ptr;
+		int source_fd, dest_fd, rdlen;
+
+		memset(tmp_buff,0,BUFSIZ+1);
+
+		ptr=strrchr(initpath,'/');
+		if(ptr && ptr-initpath<BUFSIZ) {
+			strncpy(tmp_buff,initpath,ptr-initpath);
+			snprintf(tmp_buff,BUFSIZ,"%s/menu-FCONFBKP.old",tmp_buff);
+			dest_fd = open(tmp_buff,O_WRONLY|O_TRUNC|O_CREAT,0666);
+			source_fd = open(initpath,O_RDONLY);
+			if( dest_fd == -1 || source_fd == -1 ) {
+				if(dest_fd<0) close(dest_fd);
+				if(source_fd<0) close(source_fd);
+			} else {
+				while((rdlen=read(source_fd,tmp_buff,BUFSIZ))>0)
+					write(dest_fd,tmp_buff,rdlen);
+				close(source_fd);
+				close(dest_fd);
+			}
+		}
+	}
     file = fopen(initpath, "w");
     if (file == NULL) {
         g_print(_("Can't open %s for writing\n"), initpath);
